@@ -11,7 +11,7 @@ class SearchItem(BaseModel):
     content: str
     search_keyword: str
     url: Optional[str]
-    date: Optional[str]
+    time: Optional[str]
     img_url: Optional[str]
     source: str
     page_num: int
