@@ -145,16 +145,19 @@ class BingSpider():
             link = link[0] if len(link) >= 1 else None
             title = item.xpath("div[@class='b_title']/h2/a")
             title = title[0].xpath("string(.)") if len(title) >= 1 else ""
-            content = item.xpath("div[@class='b_caption']/p/text()")
-            content = content[0] if len(content) >= 1 else ""
-            rank = i + 1
-            if "$ensp;" in content:
-                date = content.split("$ensp;")[0]
-                content = content.split("$ensp;")[-1]
+            content = "".join(item.xpath("div[@class='b_caption']/p/text()"))
+            # if "\\u2002·\\u2002;" in content:
+            if re.findall(r"\u2002·\u2002", content):
+                date = re.split(r"\u2002·\u2002", content)[0]
+                # content = content.split("$ensp;")[-1]
             else:
                 date = ""
+            # date = content
+            content = "".join(re.split(r"\u2002·\u2002", content)[1:]) if len(content) >= 2 else ""
+            rank = i + 1
+
             try:
-                item = SearchItem(title=title, url=link, content=content, search_keyword=keyword, date=date, source = "bing", page_num=page_num, page_rank=rank)
+                item = SearchItem(title=title, url=link, content=content, search_keyword=keyword, time=date, source = "", page_num=page_num, page_rank=rank)
                 item_list.append(item.__dict__)
             except Exception as e:
                 logger.error(f"[item parse error]: {e}")
@@ -224,7 +227,7 @@ class BingSpider():
 if __name__ == "__main__":
     print("a")
     spider = BingSpider()
-    res = spider.search("海南浪淘沙网络科技有限公司")
+    res = spider.search("自称家里有50辆宾利女车主发声")
     print(res)
     # spider.start_request(["深圳市黑石互娱科技有限公司 企查查"], 0, 1)
     # kwargs = {
